#ifndef __msn_filetransferp2p_h__
#define __msn_filetransferp2p_h__

/*
 * filetransferp2p.h
 * libmsn
 *
 * Created by Tiago Salem Herrmann on 08/2007.
 * Copyright (c) 2007 Tiago Salem Herrmann. All rights reserved
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <msn/util.h>
#include <msn/switchboardserver.h>
#include <msn/passport.h>
#include <string>
#include <stdio.h>

namespace MSN 
{
    class FileTransferConnectionP2P : public Connection
    {
public:
        
        /** Are we sending or receiving the file?
         */
        typedef enum 
        {
            MSNFTP_SEND,
            MSNFTP_RECV
        } Direction;
        
        /** Are we being connected to or connecting to them?
         */
        typedef enum
        {
            MSNFTP_SERVER,
            MSNFTP_CLIENT
        } Perspective;
        
        /** How far through the process are we?
         */
        typedef enum
        {
            WAITING_FOR_CONNECTION,
            NEGOTIATING,
            TRANSFERRING
        } Progress;
        
        int direction;
        int perspective;
        int direct_connection;

        MSN::P2P::p2pSession session;
        
        FileTransferConnectionP2P(SwitchboardServerConnection & _swConnection, MSN::P2P::p2pSession & _session) : Connection(), swConnection(&_swConnection), session(_session) {};
        
        void setDirection(int direction);
        void setPerspective(int direction);
        void setDirectConnection(int direct_connection);

        virtual ~FileTransferConnectionP2P();

        /** @todo Should this really be an empty function? */
        virtual void connect(const std::string & hostname, unsigned int port) {};
        virtual void disconnect();
        virtual void dispatchCommand(std::vector<std::string> & args) {};

        virtual void socketIsWritable();
        virtual void socketConnectionCompleted();
        virtual void dataArrivedOnSocket();
        virtual NotificationServerConnection *myNotificationServer() { return switchboardConnection()->myNotificationServer(); };
protected:
        virtual void handleIncomingData();
private:
        SwitchboardServerConnection *swConnection;
        SwitchboardServerConnection *switchboardConnection() { return swConnection; };
    };
}
#endif
